#ifndef GETOPINIONSINK_H
#define GETOPINIONSINK_H
#include <QtCore>
#include <mbarcode-qt/plugininterfaces.h>
#include <mbarcode-qt/pluginaction.h>
class Plugin;
class GetOpinionSink: public PluginAction
{
    Q_OBJECT

public:
    // inherited virtuals
    GetOpinionSink(const PluginInterface *interface);

    QString getName() {return "Informed Individual Get Opinion Sink Plugin";}
    QString getText() {return "Rating from Informed Individual"; }
    QImage getImage();
    void clickAction(QWidget *parentWindow);
    void setPlugin(Plugin *plugin);
signals:
    void isReady();
private:
    Plugin *plugin;
    QImage image;
};

#endif // GETOPINIONSINK_H
